==> sailcut_1.2.2.orig.tar.gz: sailcut-1.2.2/src/sailpainter.h <==
/*
 * Copyright (C) 1993-2006 Robert & Jeremy Laine
 *
 * $Id: sailpainter.h,v 1.11 2006/01/25 21:54:02 jeremy_laine Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef SAILPAINTER_H
#define SAILPAINTER_H

#include <QPainter>
#include "geocpp/vect_geom.h"

class CSail;
class CSide;
class CPanel;
class CPanelLabel;

/** A sail painter
 *
 * @see CSailDispLabel
 */
class CSailPainter : public QPainter
{
public:
    /** Construct a new sail painter.
     *
     * @param dev the paint device we are operating on
    */
    CSailPainter(QPaintDevice *dev) : QPainter(dev)
    {}
    ;

    void draw(const CSide &side);
    void draw(const CPanel &panel);
    void draw(const CSail &sail);
    void draw(const CPanelLabel &label);
    void drawCross(const CPoint3d &p, const real size);
    void drawTextCentered(const CPoint3d &p, const QString &str);
    void drawTextCentered(const CPoint3d &p, const QStringList &lst);
    void drawLabels(const CSail &sail);

    void setFontSize(const real size, const real zoom);
    void setWindow(const CRect3d& lRect);
    CVector3d textSize(const QStringList &lst);
};

#endif

==> sailcut_1.2.4.orig.tar.gz: sailcut-1.2.4/src/sailpainter.h <==
/*
 * Copyright (C) 1993-2006 Robert & Jeremy Laine
 * See AUTHORS file for a full list of contributors.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef SAILPAINTER_H
#define SAILPAINTER_H

#include <QPainter>
#include "geocpp/geometry.h"

class CSail;
class CSide;
class CPanel;
class CPanelLabel;

/** A sail painter
 *
 * @see CSailDispLabel
 */
class CSailPainter : public QPainter
{
public:
    /** Construct a new sail painter.
     *
     * @param dev the paint device we are operating on
    */
    CSailPainter(QPaintDevice *dev) : QPainter(dev)
    {}
    ;

    void draw(const CSide &side);
    void draw(const CPanel &panel);
    void draw(const CSail &sail);
    void draw(const CPanelLabel &label);
    void drawCross(const CPoint3d &p, const real size);
    void drawTextCentered(const CPoint3d &p, const QString &str);
    void drawTextCentered(const CPoint3d &p, const QStringList &lst);
    void drawLabels(const CSail &sail);

    void setFontSize(const real size, const real zoom);
    void setWindow(const CRect3d& lRect);
    CVector3d textSize(const QStringList &lst);
};

#endif
